Index: base/win_util.h |
diff --git a/base/win_util.h b/base/win_util.h |
index 3a3373297c3bbb60e401438446d99a0e24d504b3..c2ebcd70e1014472727e85449fb0178c7dac1f59 100644 |
--- a/base/win_util.h |
+++ b/base/win_util.h |
@@ -12,7 +12,7 @@ |
#include <string> |
-#include "base/keyboard_codes.h" |
+#include "app/keyboard_codes.h" |
namespace win_util { |
@@ -113,9 +113,9 @@ std::wstring FormatMessage(unsigned messageid); |
// Uses the last Win32 error to generate a human readable message string. |
std::wstring FormatLastWin32Error(); |
-// Methods to convert base::KeyboardCode/Windows virtual key type methods. |
-WORD KeyboardCodeToWin(base::KeyboardCode keycode); |
-base::KeyboardCode WinToKeyboardCode(WORD keycode); |
+// Methods to convert app::KeyboardCode/Windows virtual key type methods. |
+WORD KeyboardCodeToWin(app::KeyboardCode keycode); |
+app::KeyboardCode WinToKeyboardCode(WORD keycode); |
// Sets the application id in given IPropertyStore. The function is intended |
// for tagging application/chromium shortcut, browser window and jump list for |